@@ -614,13 +614,13 @@ rrn_info_find_from_uri (char *uri, char *section)
       if (!section || (*section && l->reg->section && !strcmp (l->reg->section, section))) {
 	return l->reg;
       } else {
-	best_result = l->reg;
+	best_result = l;
       }
     }
     l = l->next;
   }
   
-  return best_result;
+  return best_result->reg;
 
 }
 
